.\" Automatically generated by Pandoc 2.5
.\"
.TH "tmdoc::tmdoc 0.2" "" "" "" ""
.hy
.SS NAME
.PP
\f[B]tmdoc::tmdoc\f[R] \- Literate Programming with Tcl and Markdown.
Flexible framework for mixing Markdown text and Tcl code for automatic
report generation.
The results of the Tcl code evaluation are embedded into the output
document.
.SS TABLE OF CONTENTS
.IP \[bu] 2
SYNOPSIS
.IP \[bu] 2
DESCRIPTION
.IP \[bu] 2
COMMAND
.IP \[bu] 2
EXAMPLE
.IP \[bu] 2
BASIC FORMATTING
.IP \[bu] 2
DOCUMENTATION
.IP \[bu] 2
INSTALLATION
.IP \[bu] 2
SEE ALSO
.IP \[bu] 2
CHANGES
.IP \[bu] 2
TODO
.IP \[bu] 2
AUTHOR
.IP \[bu] 2
LICENSE AND COPYRIGHT
.SS SYNOPSIS
.PP
Usage as package:
.IP
.nf
\f[C]
package require tmdoc::tmdoc
namespace import tmdoc::tmdoc
tmdoc infile ?\-outfile outputfile \-mode tangle?
\f[R]
.fi
.PP
Usage as command line application:
.IP
.nf
\f[C]
tclsh tmdoc.tcl infile ?\-\-outfile outputfile \-\-mode tangle?
\f[R]
.fi
.SS DESCRIPTION
.PP
\f[B]tmdoc::tmdoc\f[R] is a tool for literate programming.
It either evaluates Tcl code embedded within Markdown documents in
\f[I]weave\f[R] mode or it alternativly extracts Tcl code from such
documents in \f[I]tangle\f[R] mode.
The results of the Tcl code written in code chunks using backticks as
code indicators oas well as the Tcl code can be displayed or hidden by
setting code chunk options.
\f[I]tmdoc::tmdoc\f[R] can be used as Tcl package or standalone as a
console application.
.SS COMMAND
.PP
\f[B]tmdoc::tmdoc\f[R] \f[I]infile ?\[en]outfile filename \[en]mode
weave|tangle?\f[R]
.RS
.PP
Reads the inputfile \f[I]infile\f[R] and either evaluates the Tcl code
within \[cq] the code chunks in the \f[I]infile\f[R] document and adds
the evaluation results if the given mode is \f[I]weave\f[R], which is
default.
If the given mode is \f[I]tangle\f[R]
.PD 0
.P
.PD
the tcl code within code chunks is written out.
The output is either send to the \f[I]stdout\f[R] channel or to the
given \f[I]outfile\f[R].
The following arguments or options can be given:
.RE
.RS
.IP \[bu] 2
\f[I]infile\f[R] (mandatory) the file which contains Tcl code embedded
with Markdown code, usually the file has an extension \f[I].tmd\f[R]
.IP \[bu] 2
\f[I]\-outfile filename\f[R] (optional) the file where the output is
written to, default: \f[I]stdout\f[R].
.IP \[bu] 2
\f[I]\-mode weave|tangle\f[R] (optional) either \f[I]weave\f[R] for
evaluating the Tcl code or \f[I]tangle\f[R] for extracting the Tcl code,
default: \f[I]weave\f[R].
.RE
.SS EXAMPLE
.IP
.nf
\f[C]
package require tmdoc
namespace import tmdoc::tmdoc
tmdoc tmdoc\-example.tmd \-\-outfile tmdoc\-example.md
tmdoc tmdoc\-example.tmd \-\-mode tangle \-\-outfile tmdoc\-example.tcl
\f[R]
.fi
.SS BASIC FORMATTING
.PP
For a complete list of Markdown formatting commands consult the basic
Markdown syntax at
https://daringfireball.net (https://daringfireball.net/projects/markdown/syntax).
.SS Code chunks
.PP
Tcl code is embedded as chunks into the Markdown documents using
backticks.
Code blocks are started with triple backticks and indicated with the the
string \[lq]tcl\[rq] within curly braces.
See the following example.
.PP
\f[C]\f[R]{tcl} set x 1 \f[C]\f[R]
.PP
This would show both the Tcl code as well the output of the last
statement.
.PP
Within the curly braces a few chunk options can be placed in the form of
\f[I]prop=value\f[R] like in the example below:
.PP
\f[C]\f[R]{tcl label=mlabel,echo=false,results=hide} set x 1 \f[C]\f[R]
.IP \[bu] 2
\f[I]label=mlabel\f[R] option gives the chunk a label, sometimes useful
for debugging or for embedding images.
For this see below.
.IP \[bu] 2
\f[I]echo=false\f[R] \- hides the Tcl code in the output
.IP \[bu] 2
\f[I]results=hide\f[R] did not show the output of the Tcl command
.SS Inline code chunks
.PP
Short Tcl codes can be as well evaluated within the standard text flow.
For instance:
.IP
.nf
\f[C]
 The current date is \[ga]tcl clock format [clock seconds] \-format \[dq]%Y\-%m\-%d\[dq]\[ga]
\f[R]
.fi
.PP
Would insert the current date into the text.
So text inline code chunks are possible using single backticks such as
here \f[C]\[rs]\f[R]tcl set x\[ga] \[ga].
.SS Images
.PP
Inside standard code chunks as well images with Tcl can be generated
with normal Tcl code.
.PP
To support the standard chunk properties \f[I]fig=true\f[R], optionally
with \f[I]include=false\f[R] however a Tcl procedure proc must be
provided.
Below is an example to use the tklib package \f[I]canvas::snap\f[R] to
create images using the Tk canvas.
.PP
\f[C]\f[R]{tcl} package require Tk package require canvas::snap pack
[canvas .c \-background beige]
.PD 0
.P
.PD
\-padx 5 \-pady 5 \-side top \-fill both \-expand yes proc figure
{outfile} set img [canvas::snap .c] $img write $outfile \-format png }
\f[C]\f[R]
.PP
After preparing the canvas and the figure procedure the canvas can be
used for making images like in the example below:
.PP
\f[C]\f[R]{tcl,fig=true,results=hide} .c create rectangle 60 60 90 90
\-fill blue \f[C]\f[R] The code above will create a canvas figure and
embeds it automatically.
If you need more control on the figure placement you can use the option
\f[I]include=false\f[R]
.PP
\f[C]\f[R]{tcl,label=mfig,fig=true,results=hide,include=false} .c create
rectangle 65 65 85 85 \-fill blue \f[C]\f[R] You can now manually place
the figure.
The filename of the figure will be automatically created, it is the
basename of the tmd\-file and the label.
So in principle: \f[C]basename\-label.png\f[R].
You can embed the figure using Markdown figure markup such as:
.IP
.nf
\f[C]
  ![](basename\-label.png)
\f[R]
.fi
.PP
For a detailed tutorial on how to do literate programming with Tcl have
a look at the Tcl Markdown tutorial (tutorial/tmd.html)
.SS INSTALLATION
.PP
The \f[I]tmdoc::tmdoc\f[R] package needs a working installation of
Tcl8.6 or Tcl8.7.
Tcl 8.4 and 8.5 might wortk but are untested and not supported.
.PP
The \f[I]tmdoc::tmdoc\f[R] package can be installed either as command
line application or as a Tcl module.
.PP
Installation as command line application can be done by copying the
\f[C]tmdoc.tcl\f[R] as \f[C]tmdoc\f[R] to a directory which is in your
executable path.
You should make this file executable using \f[C]chmod\f[R].
.PP
Installation as Tcl module is achieved by copying the file
\f[C]tmdoc.tcl\f[R] to a place which is your Tcl module path as
\f[C]tmdoc/tmdoc\-0.2.tm\f[R] for instance.
See the tm manual page (https://www.tcl.tk/man/tcl8.6/TclCmd/tm.htm)
.PP
Installation as Tcl package is done if you copy the \f[I]tmdoc\f[R]
folder with all it\[cq]s files to a path that belongs to the list of
your Tcl library paths.
.SS DOCUMENTATION
.PP
The script contains it\[cq]s own documentation written in Markdown.
The documentation can be extracted by using the commandline swith
\f[I]\[en]man\f[R]
.IP
.nf
\f[C]
tclsh tmdoc.tcl \-\-man
\f[R]
.fi
.PP
The documentation can be converted to HTML, PDF or Unix manual pages
with the aid of a Markdown processor such as pandoc ot the Tcl
application
mkdoc (https://chiselapp.com/user/dgroth/repository/tclcode).
Here an example for the conversion using mkdoc
.IP
.nf
\f[C]
\f[R]
.fi
.SS SEE ALSO
.IP \[bu] 2
tmdoc tutorial (tutorial/tmd.html)
.IP \[bu] 2
mkdoc (https://chiselapp.com/user/dgroth/repository/tclcode) for
embedding Markdown code into Tcl code as source code documentation.
.IP \[bu] 2
pandoc (https://pandoc.org/) a universal document converter
.SS CHANGES
.IP \[bu] 2
2020\-02\-19 Release 0.1
.IP \[bu] 2
2020\-02\-21 Release 0.2
.RS 2
.IP \[bu] 2
docu updates
.IP \[bu] 2
nonewline puts fix
.IP \[bu] 2
\f[I]\-outfile filename\f[R] option
.IP \[bu] 2
\f[I]\-mode tangle\f[R] option
.RE
.SS TODO
.IP \[bu] 2
LaTeX mode if file extension is twx intead of tmd
.IP \[bu] 2
fig.width, fig.height options by using args argument in figure
.IP \[bu] 2
your suggestions \&...
.SS AUTHOR(s)
.PP
The \f[B]tmdoc::tmdoc\f[R] package was written by Dr.\ Detlef Groth,
Schwielowsee, Germany.
.SS LICENSE AND COPYRIGHT
.PP
Tcl Markdown processor tmdoc::tmdoc, version 0.2
.PP
Copyright (c) 2020 Dr.\ Detlef Groth, E\-mail: <detlef(at)dgroth(dot)de>
.PP
This library is free software; you can use, modify, and redistribute it
for any purpose, provided that existing copyright notices are retained
in all copies and that this notice is included verbatim in any
distributions.
.PP
This software is distributed WITHOUT ANY WARRANTY; without even the
implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
